@@ -57,13 +57,13 @@ options :: [OptDescr (Options -> IO Options)]
 options =
      [ Option "h?"      ["help"]
               (NoArg $ \_ -> do
-                    hPutStr stderr (usageInfo header options)
+                    putStr (usageInfo header options)
                     exitSuccess
               )
               "show this help"
      , Option "V"       ["version"]
               (NoArg $ \_ -> do
-                    hPutStrLn stderr versionStr
+                    putStrLn versionStr
                     exitSuccess
               )
               "show the version number"
@@ -189,7 +189,8 @@ main = do
         (_height, width) <- getTermSize
         hPutChar stderr '\r'
         hPutStr stderr $
-            mkProgressBar (msg "Processing data") percentage (fromIntegral width) (fromIntegral b) (fromIntegral size)
+            mkProgressBar (msg "Processing data") percentage (fromIntegral width) $
+                Progress (fromIntegral b) (fromIntegral size)
         when  (fromIntegral b >= fromIntegral size) $ do
             hPutChar stderr '\r'
             hPutStr stderr (replicate width ' ')
